@@ -31,7 +31,7 @@
 #include <pan/data-impl/data-io.h>
 #include <pan/data-impl/memchunk.h>
 #include <pan/data-impl/profiles.h>
-#include <pan/data-impl/rules-filter.h>
+#include <pan/data-impl/article-rules.h>
 #include <pan/data/article-cache.h>
 #include <pan/data/article.h>
 #include <pan/data/data.h>
@@ -111,22 +111,22 @@ class DataImpl final : public Data, public TaskArchive, public ProfilesImpl
       return _certstore;
     }
 
-    virtual Prefs &get_prefs()
+    Prefs &get_prefs() override
     {
       return _prefs;
     }
 
-    virtual Prefs const &get_prefs() const
+    Prefs const &get_prefs() const override
     {
       return _prefs;
     }
 
-    virtual Queue *get_queue()
+    Queue *get_queue() override
     {
       return _queue;
     }
 
-    virtual Queue const *get_queue() const
+    Queue *get_queue() const override
     {
       return _queue;
     }
@@ -570,8 +570,7 @@ class DataImpl final : public Data, public TaskArchive, public ProfilesImpl
         size_t size() const override;
         void set_filter(const ShowType show_type = SHOW_ARTICLES,
                         FilterInfo const *criteria = nullptr) final override;
-        void set_rules(const ShowType show_type = SHOW_ARTICLES,
-                       RulesInfo const *rules = nullptr) final override;
+        void set_rules(RulesInfo const *rules = nullptr) final override;
 
       public:
         void articles_changed(quarks_t const &mids, bool do_refilter);
@@ -764,7 +763,7 @@ class DataImpl final : public Data, public TaskArchive, public ProfilesImpl
 
   public:
     const ArticleFilter _article_filter;
-    RulesFilter _rules_filter;
+    ArticleRules _article_rules;
 
   private:
     mutable guint newsrc_autosave_id;
