@@ -194,7 +194,7 @@ ArticleCache ::ArticleCache(StringView const &path,
       }
     }
     g_dir_close(dir);
-    debug("loaded " << _mid_to_info.size() << " articles into cache from "
+    pan_debug("loaded " << _mid_to_info.size() << " articles into cache from "
                     << _path);
   }
 }
@@ -243,7 +243,7 @@ ArticleCache :: get_filename (char * buf, int buflen, const Quark& mid) const
 ArticleCache :: CacheResponse
 ArticleCache :: add (const Quark& message_id, const StringView& article, const bool virtual_file)
 {
-  debug ("adding " << message_id << ", which is " << article.len << " bytes long");
+  pan_debug ("adding " << message_id << ", which is " << article.len << " bytes long");
 
   CacheResponse res;
   res.type = CACHE_IO_ERR;
@@ -353,13 +353,13 @@ ArticleCache :: resize (guint64 max_bytes)
         unlink (buf);
         _current_bytes -= it->_size;
         removed.insert (mid);
-        debug ("removing [" << mid << "] as we resize the queue");
+        pan_debug ("removing [" << mid << "] as we resize the queue");
         _mid_to_info.erase (mid);
       }
     }
   }
 
-  debug ("cache expired " << removed.size() << " articles, "
+  pan_debug ("cache expired " << removed.size() << " articles, "
          "has " << _mid_to_info.size() << " active "
          "and " << _locks.size() << " locked.");
 
@@ -393,26 +393,26 @@ ArticleCache :: get_message_file_stream (const Quark& mid) const
       }
    }
 
-   debug ("file stream for " << mid << ": " << retval);
+   pan_debug ("file stream for " << mid << ": " << retval);
    return retval;
 }
 
 /*private*/ GMimeStream*
 ArticleCache :: get_message_mem_stream (const Quark& mid) const
 {
-   debug ("mem stream got quark " << mid);
+   pan_debug ("mem stream got quark " << mid);
    GMimeStream * retval (nullptr);
 
    char filename[PATH_MAX];
    if (get_filename (filename, sizeof(filename), mid))
    {
-      debug ("mem stream loading filename " << filename);
+      pan_debug ("mem stream loading filename " << filename);
       gsize len (0);
       char * buf (nullptr);
       GError * err (nullptr);
 
       if (g_file_get_contents (filename, &buf, &len, &err)) {
-         debug ("got the contents, calling mem_new_with_buffer");
+         pan_debug ("got the contents, calling mem_new_with_buffer");
          retval = g_mime_stream_mem_new_with_buffer (buf, len);
          g_free (buf);
       } else {
@@ -421,7 +421,7 @@ ArticleCache :: get_message_mem_stream (const Quark& mid) const
       }
    }
 
-   debug ("mem stream for " << mid << ": " << retval);
+   pan_debug ("mem stream for " << mid << ": " << retval);
    return retval;
 }
 
@@ -433,7 +433,7 @@ GMimeMessage*
 ArticleCache :: get_message (const mid_sequence_t& mids) const
 #endif
 {
-   debug ("trying to get a message with " << mids.size() << " parts");
+   pan_debug ("trying to get a message with " << mids.size() << " parts");
    GMimeMessage * retval = NULL;
 
    // load the streams
