@@ -22,9 +22,10 @@
 #include <config.h>
 #include <glib/gi18n.h>
 #include <glib.h>
-#include "gtk-compat.h"
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #ifdef HAVE_GTKSPELL
-#include <enchant-2/enchant.h>
+#include <enchant.h>
 #endif
 #include <pan/general/debug.h>
 #include <pan/general/macros.h>
@@ -33,12 +34,10 @@
 #include "hig.h"
 #include "pad.h"
 #include "pan-file-entry.h"
-#include "gtk-compat.h"
 #include "pan-colors.h"
 
 #include <iostream>
 
-#include <pan/general/null.h>
 
 namespace pan {
 
@@ -62,9 +61,9 @@ namespace
   }
 
 #ifdef HAVE_GTKSPELL
-  static EnchantBroker *broker = NULL;
-  static GList *langs = NULL;
-  static GtkTextView* view = NULL;
+  static EnchantBroker *broker = nullptr;
+  static GList *langs = nullptr;
+  static GtkTextView* view = nullptr;
   Langs l;
 #endif
   void init_spell()
@@ -183,7 +182,7 @@ namespace
   create_spellcheck_combo_box ( const Quark      & group,
                                 const GroupPrefs & group_prefs)
   {
-    GtkWidget * w(NULL);
+    GtkWidget * w(nullptr);
 
 #ifdef HAVE_GTKSPELL
     init_spell();
@@ -214,7 +213,7 @@ namespace
 
     GtkCellRenderer * renderer (gtk_cell_renderer_text_new ());
     gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (w), renderer, TRUE);
-    gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), renderer, "text", 0, NULL);
+    gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (w), renderer, "text", 0, nullptr);
 
     if (valid) gtk_combo_box_set_active_iter (GTK_COMBO_BOX(w), &storeit);
 
@@ -226,8 +225,8 @@ namespace
   void color_set_cb (GtkColorButton* b, gpointer p)
   {
     GroupPrefsDialog* dialog = static_cast<GroupPrefsDialog*>(p);
-    GdkColor val;
-    gtk_color_button_get_color (b, &val);
+    GdkRGBA val;
+    gtk_color_chooser_get_rgba ((GtkColorChooser*)b, &val);
     {
       foreach_const (quarks_v, dialog->get_groups(), it)
         dialog->get_prefs().set_group_color(*it, val);
@@ -241,9 +240,9 @@ namespace
     const PanColors& colors (PanColors::get());
     const std::string& def_fg (colors.def_fg);
     const std::string& fg (prefs.get_color_str("group-pane-color-fg", def_fg));
-    const GdkColor& val (gprefs.get_group_color (group, fg));
+    const GdkRGBA& val (gprefs.get_group_color (group, fg));
 
-    GtkWidget * b = gtk_color_button_new_with_color (&val);
+    GtkWidget * b = gtk_color_button_new_with_rgba(&val);
     g_signal_connect (b, "color-set", G_CALLBACK(color_set_cb), dialog);
 
     return b;
@@ -266,7 +265,7 @@ GroupPrefsDialog :: GroupPrefsDialog (Data            & data,
                                                     parent_window,
                                                     GTK_DIALOG_DESTROY_WITH_PARENT,
                                                     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-                                                    NULL);
+                                                    nullptr);
   gtk_window_set_role (GTK_WINDOW(dialog), "pan-group-dialog");
   g_signal_connect (dialog, "response", G_CALLBACK(response_cb), this);
   g_signal_connect_swapped (dialog, "destroy", G_CALLBACK(delete_dialog), this);
@@ -293,7 +292,7 @@ GroupPrefsDialog :: GroupPrefsDialog (Data            & data,
   HIG :: workarea_add_row (t, &row, _("Character _encoding:"), w);
 
   w = _save_path = file_entry_new (_("Directory for Saving Attachments"));
-  char * pch = g_build_filename (g_get_home_dir(), "News", NULL);
+  char * pch = g_build_filename (g_get_home_dir(), "News", nullptr);
   std::string dir (_prefs.get_string ("default-save-attachments-path", pch));
   if (groups.size() == 1)
     dir = _group_prefs.get_string (groups[0], "default-group-save-path", dir);
