@@ -205,33 +205,25 @@ GroupPrefs :: set_from_file (const StringView& filename)
     from_string (s);
 }
 
-std::string
-GroupPrefs :: color_to_string (const GdkColor& c)
-{
-  char buf[8];
-  g_snprintf (buf, sizeof(buf), "#%02x%02x%02x", c.red/0x100, c.green/0x100, c.blue/0x100);
-  return buf;
-}
-
 std::string
 GroupPrefs :: get_group_color_str (const Quark& group) const
 {
   if (!_prefs[group].get_colors().count("group-color"))
     return "";
-  const GdkColor& col (_prefs[group].get_colors()["group-color"]);
-  return color_to_string (col);
+  const GdkRGBA& col (_prefs[group].get_colors()["group-color"]);
+  return gdk_rgba_to_string (&col);
 }
 
-GdkColor
+GdkRGBA
 GroupPrefs :: get_group_color (const Quark& group, const StringView& fallback_str) const
 {
-  GdkColor fallback;
-  gdk_color_parse (fallback_str.to_string().c_str(), &fallback);
+  GdkRGBA fallback;
+  gdk_rgba_parse (&fallback, fallback_str.to_string().c_str());
   return _prefs[group].get_color("group-color", fallback);
 }
 
 void
-GroupPrefs :: set_group_color (const Quark& group, const GdkColor& color)
+GroupPrefs :: set_group_color (const Quark& group, const GdkRGBA& color)
 {
 	_prefs[group].set_color("group-color", color);
 }
