@@ -13,13 +13,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 #ifndef LOG_UI_H
 #define LOG_UI_H
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include "prefs.h"
 
 namespace pan
@@ -28,6 +29,10 @@ namespace pan
    * @ingroup GUI
    */
   GtkWidget* log_dialog_new (Prefs& prefs, GtkWindow* parent);
+
+  gboolean on_button_pressed (GtkWidget *treeview, GdkEventButton *event, gpointer userdata);
+  void do_popup_menu (GtkWidget *treeview, GdkEventButton *event, gpointer userdata);
+
 }
 
 #endif
