@@ -20,7 +20,9 @@
 #ifndef PREFS_UI_H
 #define PREFS_UI_H
 
-#include "gtk-compat.h"
+#include <list>
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include <pan/gui/prefs.h>
 #include <pan/gui/group-prefs.h>
 
@@ -44,7 +46,7 @@ namespace pan
 
     public:
       PrefsDialog (Prefs&, GtkWindow*) ;
-      ~PrefsDialog () { }
+      ~PrefsDialog ();
       Prefs& prefs () { return _prefs; }
       GtkWidget* notebook () { return _notebook; }
       GtkWidget* root() { return _root; }
@@ -60,13 +62,14 @@ namespace pan
       GtkWidget* _root;
       GtkWidget* charset_label;
       GtkWidget* _notebook;
+      std::list<CallBackData*> shortcut_ptr_list;
 
       void update_default_charset_label(const StringView&);
 
       void on_prefs_flag_changed (const StringView& key, bool value) override;
       void on_prefs_int_changed (const StringView& key, int color) override {}
       void on_prefs_string_changed (const StringView& key, const StringView& value) override;
-      void on_prefs_color_changed (const StringView& key, const GdkColor& color) override {}
+      void on_prefs_color_changed (const StringView& key, const GdkRGBA& color) override {}
 
       const char* _hotkey;
 
