@@ -1,14 +1,14 @@
 #ifndef __SCORE_ADD_UI_H__
 #define __SCORE_ADD_UI_H__
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
+#include <gdk/gdk.h>
 #include <pan/data/article.h>
 #include <pan/data/data.h>
 
 namespace pan
 {
-  /** 
+  /**
    * Dialog for creating a new entry for the Scorefile.
    * @ingroup GUI
    */
