@@ -13,8 +13,8 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
+ *
  */
 
 /*********************
@@ -31,14 +31,16 @@
 #include <climits>
 #include <ctime>
 #include <vector>
+#include <sstream>
 
 extern "C"
 {
   #include <ctype.h>
   #include <unistd.h>
-  #include <glib/gi18n.h>
+  #include <sys/time.h>
 }
 
+#include <glib/gi18n.h>
 #include <pan/general/debug.h>
 #include <pan/general/macros.h>
 #include <pan/general/log.h>
@@ -79,6 +81,10 @@ gnksa_init (void)
 	int i;
 	unsigned char ch;
 
+  /* '!' (char)33 is allowed for message-ids
+  http://tools.ietf.org/html/rfc5322#section-3.2.3
+  http://tools.ietf.org/html/rfc5536#section-3.1.3
+  */
 	for (ch=0; ch<UCHAR_MAX; ++ch) {
 		_unquoted_chars[ch] = isgraph(ch) && ch!='!' && ch!='(' && ch!=')' && ch!='<'
 		                                  && ch!='>' && ch!='@' && ch!=',' && ch!=';'
@@ -103,6 +109,16 @@ gnksa_init (void)
 }
 #else
 
+static char _unquoted_chars[UCHAR_MAX] = {
+0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,1,1,
+0,0,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
+1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,};
+
+/*
 static char _unquoted_chars[UCHAR_MAX] = {
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,
 0,0,1,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,0,0,0,1,0,1,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,
@@ -112,6 +128,24 @@ static char _unquoted_chars[UCHAR_MAX] = {
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,};
 
+char   : 0
+char ! : 0
+char " : 0
+char # : 1
+char $ : 1
+char % : 1
+char & : 1
+char ' : 1
+char ( : 0
+char ) : 0
+char * : 1
+char + : 1
+char , : 0
+char - : 1
+char . : 0
+
+*/
+
 #endif
 
 static char _quoted_chars[UCHAR_MAX] = {
@@ -165,7 +199,7 @@ read_space (const char * start, const char ** end)
 		return true;
 	}
 	return false;
-	
+
 }
 
 static bool
@@ -314,7 +348,7 @@ gnksa_check_domain_literal (const StringView& domain)
 	bool need_closing_brace;
 	const char * pch;
 
-	// parse domain literal into ip number 
+	// parse domain literal into ip number
 
 	pch = domain.str;
 	need_closing_brace = *pch == '[';
@@ -366,11 +400,11 @@ GNKSA :: check_domain (const StringView& domain)
    while (mydomain.pop_token (token, '.'))
       ++label_qty;
 
-   // make sure we have more than one label in the domain 
+   // make sure we have more than one label in the domain
    if (label_qty < 2)
       return GNKSA::SINGLE_DOMAIN;
 
-   // check for illegal labels 
+   // check for illegal labels
    mydomain = domain;
    for (int i=0; i<label_qty-1; ++i) {
       mydomain.pop_token (token, '.');
@@ -380,14 +414,14 @@ GNKSA :: check_domain (const StringView& domain)
          return GNKSA::ILLEGAL_LABEL_HYPHEN;
    }
 
-   // last label -- toplevel domain 
+   // last label -- toplevel domain
    mydomain.pop_token (token, '.');
    switch (token.len)
    {
       case 1:
          if (isdigit((unsigned char)*token.str))
             return gnksa_check_domain_literal (domain);
-         // single-letter TLDs dont exist 
+         // single-letter TLDs dont exist
          return GNKSA::ILLEGAL_DOMAIN;
 
       case 2:
@@ -418,7 +452,7 @@ namespace
   int
   check_localpart (const StringView& localpart)
   {
-    // make sure it's not empty... 
+    // make sure it's not empty...
     if (localpart.empty())
       return GNKSA::LOCALPART_MISSING;
 
@@ -522,7 +556,7 @@ namespace
          addrtype = ADDRTYPE_OLDSTYLE;
 
          // address part
-         StringView myaddr (myfrom.substr (0, lparen));
+         StringView myaddr (myfrom.substr (nullptr, lparen));
          myaddr.trim ();
          addr = myaddr;
          if (strict) {
@@ -532,13 +566,13 @@ namespace
          }
 
          // real name part
-         StringView myname (myfrom.substr (lparen+1, 0));
+         StringView myname (myfrom.substr (lparen+1, nullptr));
          myname.trim ();
          if (myname.back() != ')')
             return GNKSA::RPAREN_MISSING;
 
          myname = myname.substr (NULL, myname.end()-1);
-         const char * end = 0;
+         const char * end = nullptr;
          if (strict && (!read_paren_phrase(myname.str,&end) || end==NULL))
             return GNKSA::ILLEGAL_PAREN_PHRASE;
 
@@ -623,12 +657,12 @@ GNKSA :: do_check_from (const StringView   & from,
 {
    int addrtype = 0;
 
-   // split from 
+   // split from
    addr.clear ();
    name.clear ();
    int retval = split_from (from, addr, name, addrtype, strict);
 
-   // check address 
+   // check address
    if (retval==OK && !addr.empty())
       retval = check_address (addr);
 
@@ -681,7 +715,7 @@ namespace
     *
     * The purpose of this function is to remove severely broken,
     * usually suntactically-invalid Message-IDs, such as those
-    * missing '<', '@', or '>'. 
+    * missing '<', '@', or '>'.
     *
     * However we want to retain Message-IDs that might be sloppy,
     * such as ones that have possibly-invalid domains.
@@ -713,7 +747,7 @@ namespace
       if (pch == NULL)
          return GNKSA::ATSIGN_MISSING;
 
-      // check the domain name 
+      // check the domain name
       StringView domain (tmp.substr (pch+1, NULL));
       --domain.len; // remove trailing '>'
       if (domain.empty())
@@ -747,14 +781,14 @@ GNKSA :: remove_broken_message_ids_from_references (const StringView& references
       break;
 
     // find the end of the message-id
-    v = v.substr (begin+1, 0);
+    v = v.substr (begin+1, nullptr);
     const char * end = v.strpbrk ("<> ");
     if (!end)
       end = v.end();
     else if (*end == '>')
       ++end;
-    v = v.substr (end, 0);
-                                                                                     
+    v = v.substr (end, nullptr);
+
     // check the message-id for validity
     if (check_message_id (StringView(begin, end-begin)) == GNKSA::OK) {
       s.insert (s.end(), begin, end);
@@ -798,6 +832,7 @@ GNKSA :: trim_references (const StringView& refs, size_t cutoff)
 **/
 
 static const char* default_domain = "nospam.com";
+static MTRand rng;
 
 /**
  * thus spake son-of-1036: "the most popular method of generating local parts
@@ -808,23 +843,22 @@ static const char* default_domain = "nospam.com";
 std::string
 GNKSA :: generate_message_id (const StringView& domain)
 {
-   std::string s;
+   static bool rand_inited (false);
+   if (!rand_inited)
+   {
+     rng.seed();
+     rand_inited = true;
+   }
 
-   // add unique local part to message-id 
-   s += "pan.";
-   const time_t now (time(NULL));
-   struct tm local_now = *gmtime (&now);
-   char buf[64];
-   std::strftime (buf, sizeof(buf), "%Y.%m.%d.%H.%M.%S", &local_now);
-   s += buf;
-
-   // delimit
-   s += '@';
-
-   // add domain
-   s += domain.empty() ? default_domain : domain.to_string();
-
-   return s;
+   std::stringstream out;
+   struct timeval tv;
+   out << "pan$";
+   gettimeofday (&tv, NULL);
+   out << std::hex << tv.tv_usec << "$" << std::hex
+       << rng.randInt() << "$" << std::hex << rng.randInt() << "$"
+       << std::hex << rng.randInt();
+   out << '@' << (domain.empty() ? default_domain : domain);
+   return out.str();
 }
 
 std::string
@@ -832,7 +866,7 @@ GNKSA :: generate_message_id_from_email_address (const StringView& addr)
 {
    StringView domain;
 
-   // find the domain in the email address 
+   // find the domain in the email address
    if (!addr.empty()) {
       const char * pch = addr.strchr ('@');
       if (pch != NULL)
@@ -879,7 +913,7 @@ GNKSA :: generate_references (const StringView   & references,
 ***/
 
 GNKSA::SigType
-GNKSA::is_signature_delimiter (const StringView& line) 
+GNKSA::is_signature_delimiter (const StringView& line)
 {
    switch (line.len) {
       case 2: if (!strncmp (line.str,"--"   ,2)) return SIG_NONSTANDARD;
@@ -948,6 +982,6 @@ GNKSA :: remove_signature (StringView& body)
    int sig_point (-1);
    const bool has_signature (find_signature_delimiter (body, sig_point) != SIG_NONE);
    if (has_signature)
-      body = body.substr (0, body.str+sig_point);
+      body = body.substr (nullptr, body.str+sig_point);
    return has_signature;
 }
